@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2020-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -278,7 +278,8 @@ void testing_gesvdj_bad_arg()
         //                             &size_W,
         //                             params,
         //                             bc);
-        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        // size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr ? size_W : sizeof(T) * size_W;
+        // device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         // if(size_W)
         //     CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -337,7 +338,10 @@ void testing_gesvdj_bad_arg()
                                     &size_W,
                                     params,
                                     bc);
-        device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr
+                             ? size_W
+                             : sizeof(T) * size_W;
+        device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         if(size_W)
             CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -513,21 +517,21 @@ void gesvdj_getError(const hipsolverHandle_t handle,
     // CPU lapack
     // Only singular values needed
     for(int b = 0; b < bc; ++b)
-        cblas_gesvd<T>('N',
-                       'N',
-                       m,
-                       n,
-                       hA[b],
-                       lda,
-                       hS[b],
-                       nullptr,
-                       ldu,
-                       nullptr,
-                       ldv,
-                       hWork.data(),
-                       size_W,
-                       hE.data(),
-                       hinfo[b]);
+        cpu_gesvd<T>('N',
+                     'N',
+                     m,
+                     n,
+                     hA[b],
+                     lda,
+                     hS[b],
+                     nullptr,
+                     ldu,
+                     nullptr,
+                     ldv,
+                     hWork.data(),
+                     size_W,
+                     hE.data(),
+                     hinfo[b]);
 
     // Check info for non-convergence
     *max_err = 0;
@@ -653,21 +657,21 @@ void gesvdj_getPerfData(const hipsolverHandle_t handle,
         // cpu-lapack performance (only if not in perf mode)
         *cpu_time_used = get_time_us_no_sync();
         for(int b = 0; b < bc; ++b)
-            cblas_gesvd<T>(svect,
-                           svect,
-                           m,
-                           n,
-                           hA[b],
-                           lda,
-                           hS[b],
-                           hU[b],
-                           ldu,
-                           hV[b],
-                           ldv_trans,
-                           hWork.data(),
-                           size_W,
-                           hE.data(),
-                           hinfo[b]);
+            cpu_gesvd(svect,
+                      svect,
+                      m,
+                      n,
+                      hA[b],
+                      lda,
+                      hS[b],
+                      hU[b],
+                      ldu,
+                      hV[b],
+                      ldv_trans,
+                      hWork.data(),
+                      size_W,
+                      hE.data(),
+                      hinfo[b]);
         *cpu_time_used = get_time_us_no_sync() - *cpu_time_used;
     }
 
@@ -888,10 +892,12 @@ void testing_gesvdj(Arguments& argus)
                                 &size_W,
                                 params,
                                 bc);
+    size_t bytes_W
+        = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr ? size_W : sizeof(T) * size_W;
 
     if(argus.mem_query)
     {
-        rocsolver_bench_inform(inform_mem_query, size_W);
+        rocsolver_bench_inform(inform_mem_query, bytes_W);
         return;
     }
 
@@ -912,7 +918,7 @@ void testing_gesvdj(Arguments& argus)
     device_strided_batch_vector<T>   dV(size_V, 1, stV, bc);
     device_strided_batch_vector<T>   dU(size_U, 1, stU, bc);
     device_strided_batch_vector<int> dinfo(1, 1, 1, bc);
-    device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+    device_strided_batch_vector<T>   dWork(bytes_W, 1, bytes_W, 1); // bytes_W accounts for bc
     if(size_S)
         CHECK_HIP_ERROR(dS.memcheck());
     if(size_V)
