@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2021-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -271,7 +271,8 @@ void testing_syevdx_heevdx_bad_arg()
         //                                    hNev.data(),
         //                                    dW.data(),
         //                                    &size_W);
-        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        // size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr ? size_W : sizeof(T) * size_W;
+        // device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         // if(size_W)
         //     CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -323,7 +324,10 @@ void testing_syevdx_heevdx_bad_arg()
                                            hNev.data(),
                                            dW.data(),
                                            &size_W);
-        device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr
+                             ? size_W
+                             : sizeof(T) * size_W;
+        device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         if(size_W)
             CHECK_HIP_ERROR(dWork.memcheck());
 
@@ -493,27 +497,27 @@ void syevdx_heevdx_getError(const hipsolverHandle_t   handle,
 
     // CPU lapack
     for(int b = 0; b < bc; ++b)
-        cblas_syevx_heevx<T>(evect,
-                             erange,
-                             uplo,
-                             n,
-                             hA[b],
-                             lda,
-                             vl,
-                             vu,
-                             il,
-                             iu,
-                             abstol,
-                             hNev[b],
-                             hW[b],
-                             Z.data(),
-                             lda,
-                             work.data(),
-                             size_work,
-                             rwork.data(),
-                             iwork.data(),
-                             ifail.data(),
-                             hinfo[b]);
+        cpu_syevx_heevx(evect,
+                        erange,
+                        uplo,
+                        n,
+                        hA[b],
+                        lda,
+                        vl,
+                        vu,
+                        il,
+                        iu,
+                        abstol,
+                        hNev[b],
+                        hW[b],
+                        Z.data(),
+                        lda,
+                        work.data(),
+                        size_work,
+                        rwork.data(),
+                        iwork.data(),
+                        ifail.data(),
+                        hinfo[b]);
 
     // Check info for non-convergence
     *max_err = 0;
@@ -564,16 +568,16 @@ void syevdx_heevdx_getError(const hipsolverHandle_t   handle,
                 for(int j = 0; j < hNev[b][0]; j++)
                 {
                     alpha = T(1) / hWRes[b][j];
-                    cblas_symv_hemv(uplo,
-                                    n,
-                                    alpha,
-                                    A.data() + b * lda * n,
-                                    lda,
-                                    hARes[b] + j * lda,
-                                    1,
-                                    beta,
-                                    hA[b] + j * lda,
-                                    1);
+                    cpu_symv_hemv(uplo,
+                                  n,
+                                  alpha,
+                                  A.data() + b * lda * n,
+                                  lda,
+                                  hARes[b] + j * lda,
+                                  1,
+                                  beta,
+                                  hA[b] + j * lda,
+                                  1);
                 }
 
                 // error is ||hA - hARes|| / ||hA||
@@ -644,27 +648,27 @@ void syevdx_heevdx_getPerfData(const hipsolverHandle_t   handle,
         // cpu-lapack performance (only if not in perf mode)
         *cpu_time_used = get_time_us_no_sync();
         for(int b = 0; b < bc; ++b)
-            cblas_syevx_heevx<T>(evect,
-                                 erange,
-                                 uplo,
-                                 n,
-                                 hA[b],
-                                 lda,
-                                 vl,
-                                 vu,
-                                 il,
-                                 iu,
-                                 abstol,
-                                 hNev[b],
-                                 hW[b],
-                                 Z.data(),
-                                 lda,
-                                 work.data(),
-                                 size_work,
-                                 rwork.data(),
-                                 iwork.data(),
-                                 ifail.data(),
-                                 hinfo[b]);
+            cpu_syevx_heevx(evect,
+                            erange,
+                            uplo,
+                            n,
+                            hA[b],
+                            lda,
+                            vl,
+                            vu,
+                            il,
+                            iu,
+                            abstol,
+                            hNev[b],
+                            hW[b],
+                            Z.data(),
+                            lda,
+                            work.data(),
+                            size_work,
+                            rwork.data(),
+                            iwork.data(),
+                            ifail.data(),
+                            hinfo[b]);
         *cpu_time_used = get_time_us_no_sync() - *cpu_time_used;
     }
 
@@ -844,10 +848,13 @@ void testing_syevdx_heevdx(Arguments& argus)
                                        (int*)nullptr,
                                        (S*)nullptr,
                                        &size_Work);
+    size_t bytes_Work = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr
+                            ? size_Work
+                            : sizeof(T) * size_Work;
 
     if(argus.mem_query)
     {
-        rocsolver_bench_inform(inform_mem_query, size_Work);
+        rocsolver_bench_inform(inform_mem_query, bytes_Work);
         return;
     }
 
@@ -862,7 +869,8 @@ void testing_syevdx_heevdx(Arguments& argus)
     // device
     device_strided_batch_vector<S>   dW(size_W, 1, stW, bc);
     device_strided_batch_vector<int> dinfo(1, 1, 1, bc);
-    device_strided_batch_vector<T>   dWork(size_Work, 1, size_Work, bc);
+    device_strided_batch_vector<T>   dWork(
+        bytes_Work, 1, bytes_Work, 1); // bytes_Work accounts for bc
     if(size_W)
         CHECK_HIP_ERROR(dW.memcheck());
     CHECK_HIP_ERROR(dinfo.memcheck());
@@ -1018,9 +1026,9 @@ void testing_syevdx_heevdx(Arguments& argus)
     }
 
     // validate results for rocsolver-test
-    // using n * machine_precision as tolerance
+    // using 3 * n * machine_precision as tolerance
     if(argus.unit_check)
-        ROCSOLVER_TEST_CHECK(T, max_error, n);
+        ROCSOLVER_TEST_CHECK(T, max_error, 3 * n);
 
     // output results for rocsolver-bench
     if(argus.timing)
