@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2020-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2020-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,7 +25,7 @@
 
 #include "clientcommon.hpp"
 
-template <bool FORTRAN, typename T, typename U, typename V>
+template <testAPI_t API, typename T, typename U, typename V>
 void sytrf_checkBadArgs(const hipsolverHandle_t   handle,
                         const hipsolverFillMode_t uplo,
                         const int                 n,
@@ -41,12 +41,11 @@ void sytrf_checkBadArgs(const hipsolverHandle_t   handle,
 {
     // handle
     EXPECT_ROCBLAS_STATUS(
-        hipsolver_sytrf(
-            FORTRAN, nullptr, uplo, n, dA, lda, stA, dIpiv, stP, dWork, lwork, dinfo, bc),
+        hipsolver_sytrf(API, nullptr, uplo, n, dA, lda, stA, dIpiv, stP, dWork, lwork, dinfo, bc),
         HIPSOLVER_STATUS_NOT_INITIALIZED);
 
     // values
-    EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(FORTRAN,
+    EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(API,
                                           handle,
                                           hipsolverFillMode_t(-1),
                                           n,
@@ -65,20 +64,20 @@ void sytrf_checkBadArgs(const hipsolverHandle_t   handle,
     // pointers
     EXPECT_ROCBLAS_STATUS(
         hipsolver_sytrf(
-            FORTRAN, handle, uplo, n, (T) nullptr, lda, stA, dIpiv, stP, dWork, lwork, dinfo, bc),
+            API, handle, uplo, n, (T) nullptr, lda, stA, dIpiv, stP, dWork, lwork, dinfo, bc),
         HIPSOLVER_STATUS_INVALID_VALUE);
     EXPECT_ROCBLAS_STATUS(
         hipsolver_sytrf(
-            FORTRAN, handle, uplo, n, dA, lda, stA, (U) nullptr, stP, dWork, lwork, dinfo, bc),
+            API, handle, uplo, n, dA, lda, stA, (U) nullptr, stP, dWork, lwork, dinfo, bc),
         HIPSOLVER_STATUS_INVALID_VALUE);
     EXPECT_ROCBLAS_STATUS(
         hipsolver_sytrf(
-            FORTRAN, handle, uplo, n, dA, lda, stA, dIpiv, stP, dWork, lwork, (U) nullptr, bc),
+            API, handle, uplo, n, dA, lda, stA, dIpiv, stP, dWork, lwork, (U) nullptr, bc),
         HIPSOLVER_STATUS_INVALID_VALUE);
 #endif
 }
 
-template <bool FORTRAN, bool BATCHED, bool STRIDED, typename T>
+template <testAPI_t API, bool BATCHED, bool STRIDED, typename T>
 void testing_sytrf_bad_arg()
 {
     // safe arguments
@@ -101,13 +100,14 @@ void testing_sytrf_bad_arg()
         // CHECK_HIP_ERROR(dInfo.memcheck());
 
         // int size_W;
-        // hipsolver_sytrf_bufferSize(FORTRAN, handle, n, dA.data(), lda, &size_W);
-        // device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        // hipsolver_sytrf_bufferSize(API, handle, n, dA.data(), lda, &size_W);
+        // size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr ? size_W : sizeof(T) * size_W;
+        // device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         // if(size_W)
         //     CHECK_HIP_ERROR(dWork.memcheck());
 
         // // check bad arguments
-        // sytrf_checkBadArgs<FORTRAN>(handle,
+        // sytrf_checkBadArgs<API>(handle,
         //                             uplo,
         //                             n,
         //                             dA.data(),
@@ -131,24 +131,27 @@ void testing_sytrf_bad_arg()
         CHECK_HIP_ERROR(dInfo.memcheck());
 
         int size_W;
-        hipsolver_sytrf_bufferSize(FORTRAN, handle, n, dA.data(), lda, &size_W);
-        device_strided_batch_vector<T> dWork(size_W, 1, size_W, bc);
+        hipsolver_sytrf_bufferSize(API, handle, n, dA.data(), lda, &size_W);
+        size_t bytes_W = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr
+                             ? size_W
+                             : sizeof(T) * size_W;
+        device_strided_batch_vector<T> dWork(bytes_W, 1, bytes_W, 1);
         if(size_W)
             CHECK_HIP_ERROR(dWork.memcheck());
 
         // check bad arguments
-        sytrf_checkBadArgs<FORTRAN>(handle,
-                                    uplo,
-                                    n,
-                                    dA.data(),
-                                    lda,
-                                    stA,
-                                    dIpiv.data(),
-                                    stP,
-                                    dWork.data(),
-                                    size_W,
-                                    dInfo.data(),
-                                    bc);
+        sytrf_checkBadArgs<API>(handle,
+                                uplo,
+                                n,
+                                dA.data(),
+                                lda,
+                                stA,
+                                dIpiv.data(),
+                                stP,
+                                dWork.data(),
+                                size_W,
+                                dInfo.data(),
+                                bc);
     }
 }
 
@@ -187,7 +190,7 @@ void sytrf_initData(const hipsolverHandle_t   handle,
             }
 
             // shuffle rows to test pivoting
-            // always the same permuation for debugging purposes
+            // always the same permutation for debugging purposes
             for(int i = 0; i < n / 2; i++)
             {
                 for(int j = 0; j < n; j++)
@@ -207,7 +210,13 @@ void sytrf_initData(const hipsolverHandle_t   handle,
     }
 }
 
-template <bool FORTRAN, typename T, typename Td, typename Ud, typename Vd, typename Th, typename Uh>
+template <testAPI_t API,
+          typename T,
+          typename Td,
+          typename Ud,
+          typename Vd,
+          typename Th,
+          typename Uh>
 void sytrf_getError(const hipsolverHandle_t   handle,
                     const hipsolverFillMode_t uplo,
                     const int                 n,
@@ -237,7 +246,7 @@ void sytrf_getError(const hipsolverHandle_t   handle,
 
     // execute computations
     // GPU lapack
-    CHECK_ROCBLAS_ERROR(hipsolver_sytrf(FORTRAN,
+    CHECK_ROCBLAS_ERROR(hipsolver_sytrf(API,
                                         handle,
                                         uplo,
                                         n,
@@ -256,7 +265,7 @@ void sytrf_getError(const hipsolverHandle_t   handle,
 
     // CPU lapack
     for(int b = 0; b < bc; ++b)
-        cblas_sytrf<T>(uplo, n, hA[b], lda, hIpiv[b], hW.data(), size_W, hInfo[b]);
+        cpu_sytrf(uplo, n, hA[b], lda, hIpiv[b], hW.data(), size_W, hInfo[b]);
 
     // error is ||hA - hARes|| / ||hA||
     // (THIS DOES NOT ACCOUNT FOR NUMERICAL REPRODUCIBILITY ISSUES.
@@ -291,7 +300,13 @@ void sytrf_getError(const hipsolverHandle_t   handle,
     *max_err += err;
 }
 
-template <bool FORTRAN, typename T, typename Td, typename Ud, typename Vd, typename Th, typename Uh>
+template <testAPI_t API,
+          typename T,
+          typename Td,
+          typename Ud,
+          typename Vd,
+          typename Th,
+          typename Uh>
 void sytrf_getPerfData(const hipsolverHandle_t   handle,
                        const hipsolverFillMode_t uplo,
                        const int                 n,
@@ -323,7 +338,7 @@ void sytrf_getPerfData(const hipsolverHandle_t   handle,
         // cpu-lapack performance (only if not in perf mode)
         *cpu_time_used = get_time_us_no_sync();
         for(int b = 0; b < bc; ++b)
-            cblas_sytrf<T>(uplo, n, hA[b], lda, hIpiv[b], hW.data(), size_W, hInfo[b]);
+            cpu_sytrf(uplo, n, hA[b], lda, hIpiv[b], hW.data(), size_W, hInfo[b]);
         *cpu_time_used = get_time_us_no_sync() - *cpu_time_used;
     }
 
@@ -336,7 +351,7 @@ void sytrf_getPerfData(const hipsolverHandle_t   handle,
         sytrf_initData<false, true, T>(
             handle, uplo, n, dA, lda, stA, dIpiv, stP, dInfo, bc, hA, hIpiv, hInfo);
 
-        CHECK_ROCBLAS_ERROR(hipsolver_sytrf(FORTRAN,
+        CHECK_ROCBLAS_ERROR(hipsolver_sytrf(API,
                                             handle,
                                             uplo,
                                             n,
@@ -362,7 +377,7 @@ void sytrf_getPerfData(const hipsolverHandle_t   handle,
             handle, uplo, n, dA, lda, stA, dIpiv, stP, dInfo, bc, hA, hIpiv, hInfo);
 
         start = get_time_us_sync(stream);
-        hipsolver_sytrf(FORTRAN,
+        hipsolver_sytrf(API,
                         handle,
                         uplo,
                         n,
@@ -380,7 +395,7 @@ void sytrf_getPerfData(const hipsolverHandle_t   handle,
     *gpu_time_used /= hot_calls;
 }
 
-template <bool FORTRAN, bool BATCHED, bool STRIDED, typename T>
+template <testAPI_t API, bool BATCHED, bool STRIDED, typename T>
 void testing_sytrf(Arguments& argus)
 {
     // get arguments
@@ -403,7 +418,7 @@ void testing_sytrf(Arguments& argus)
     {
         if(BATCHED)
         {
-            // EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(FORTRAN,
+            // EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(API,
             //                                       handle,
             //                                       uplo,
             //                                       n,
@@ -420,7 +435,7 @@ void testing_sytrf(Arguments& argus)
         }
         else
         {
-            EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(FORTRAN,
+            EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(API,
                                                   handle,
                                                   uplo,
                                                   n,
@@ -456,7 +471,7 @@ void testing_sytrf(Arguments& argus)
     {
         if(BATCHED)
         {
-            // EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(FORTRAN,
+            // EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(API,
             //                                       handle,
             //                                       uplo,
             //                                       n,
@@ -473,7 +488,7 @@ void testing_sytrf(Arguments& argus)
         }
         else
         {
-            EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(FORTRAN,
+            EXPECT_ROCBLAS_STATUS(hipsolver_sytrf(API,
                                                   handle,
                                                   uplo,
                                                   n,
@@ -497,11 +512,13 @@ void testing_sytrf(Arguments& argus)
 
     // memory size query is necessary
     int size_W;
-    hipsolver_sytrf_bufferSize(FORTRAN, handle, n, (T*)nullptr, lda, &size_W);
+    hipsolver_sytrf_bufferSize(API, handle, n, (T*)nullptr, lda, &size_W);
+    size_t bytes_W
+        = std::getenv("HIPSOLVER_BUFFERSIZE_RETURN_BYTES") != nullptr ? size_W : sizeof(T) * size_W;
 
     if(argus.mem_query)
     {
-        rocsolver_bench_inform(inform_mem_query, size_W);
+        rocsolver_bench_inform(inform_mem_query, bytes_W);
         return;
     }
 
@@ -517,7 +534,7 @@ void testing_sytrf(Arguments& argus)
         // device_batch_vector<T>           dA(size_A, 1, bc);
         // device_strided_batch_vector<int> dIpiv(size_P, 1, stP, bc);
         // device_strided_batch_vector<int> dInfo(1, 1, 1, bc);
-        // device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+        // device_strided_batch_vector<T>   dWork(bytes_W, 1, bytes_W, 1); // bytes_W accounts for bc
         // if(size_A)
         //     CHECK_HIP_ERROR(dA.memcheck());
         // CHECK_HIP_ERROR(dInfo.memcheck());
@@ -528,7 +545,7 @@ void testing_sytrf(Arguments& argus)
 
         // // check computations
         // if(argus.unit_check || argus.norm_check)
-        //     sytrf_getError<FORTRAN, T>(handle,
+        //     sytrf_getError<API, T>(handle,
         //                                uplo,
         //                                n,
         //                                dA,
@@ -550,7 +567,7 @@ void testing_sytrf(Arguments& argus)
 
         // // collect performance data
         // if(argus.timing)
-        //     sytrf_getPerfData<FORTRAN, T>(handle,
+        //     sytrf_getPerfData<API, T>(handle,
         //                                   uplo,
         //                                   n,
         //                                   dA,
@@ -583,7 +600,7 @@ void testing_sytrf(Arguments& argus)
         device_strided_batch_vector<T>   dA(size_A, 1, stA, bc);
         device_strided_batch_vector<int> dIpiv(size_P, 1, stP, bc);
         device_strided_batch_vector<int> dInfo(1, 1, 1, bc);
-        device_strided_batch_vector<T>   dWork(size_W, 1, size_W, bc);
+        device_strided_batch_vector<T>   dWork(bytes_W, 1, bytes_W, 1); // bytes_W accounts for bc
         if(size_A)
             CHECK_HIP_ERROR(dA.memcheck());
         CHECK_HIP_ERROR(dInfo.memcheck());
@@ -594,47 +611,47 @@ void testing_sytrf(Arguments& argus)
 
         // check computations
         if(argus.unit_check || argus.norm_check)
-            sytrf_getError<FORTRAN, T>(handle,
-                                       uplo,
-                                       n,
-                                       dA,
-                                       lda,
-                                       stA,
-                                       dIpiv,
-                                       stP,
-                                       dWork,
-                                       size_W,
-                                       dInfo,
-                                       bc,
-                                       hA,
-                                       hARes,
-                                       hIpiv,
-                                       hIpivRes,
-                                       hInfo,
-                                       hInfoRes,
-                                       &max_error);
+            sytrf_getError<API, T>(handle,
+                                   uplo,
+                                   n,
+                                   dA,
+                                   lda,
+                                   stA,
+                                   dIpiv,
+                                   stP,
+                                   dWork,
+                                   size_W,
+                                   dInfo,
+                                   bc,
+                                   hA,
+                                   hARes,
+                                   hIpiv,
+                                   hIpivRes,
+                                   hInfo,
+                                   hInfoRes,
+                                   &max_error);
 
         // collect performance data
         if(argus.timing)
-            sytrf_getPerfData<FORTRAN, T>(handle,
-                                          uplo,
-                                          n,
-                                          dA,
-                                          lda,
-                                          stA,
-                                          dIpiv,
-                                          stP,
-                                          dWork,
-                                          size_W,
-                                          dInfo,
-                                          bc,
-                                          hA,
-                                          hIpiv,
-                                          hInfo,
-                                          &gpu_time_used,
-                                          &cpu_time_used,
-                                          hot_calls,
-                                          argus.perf);
+            sytrf_getPerfData<API, T>(handle,
+                                      uplo,
+                                      n,
+                                      dA,
+                                      lda,
+                                      stA,
+                                      dIpiv,
+                                      stP,
+                                      dWork,
+                                      size_W,
+                                      dInfo,
+                                      bc,
+                                      hA,
+                                      hIpiv,
+                                      hInfo,
+                                      &gpu_time_used,
+                                      &cpu_time_used,
+                                      hot_calls,
+                                      argus.perf);
     }
 
     // validate results for rocsolver-test
